summaryrefslogtreecommitdiffstats
path: root/kmymoney2/dialogs/ksplittransactiondlg.h
diff options
context:
space:
mode:
Diffstat (limited to 'kmymoney2/dialogs/ksplittransactiondlg.h')
-rw-r--r--kmymoney2/dialogs/ksplittransactiondlg.h13
1 files changed, 7 insertions, 6 deletions
diff --git a/kmymoney2/dialogs/ksplittransactiondlg.h b/kmymoney2/dialogs/ksplittransactiondlg.h
index 67a5b92..76261bd 100644
--- a/kmymoney2/dialogs/ksplittransactiondlg.h
+++ b/kmymoney2/dialogs/ksplittransactiondlg.h
@@ -51,6 +51,7 @@ class kMyMoneyLineEdit;
class KSplitTransactionDlg : public KSplitTransactionDlgDecl
{
Q_OBJECT
+ TQ_OBJECT
public:
KSplitTransactionDlg(const MyMoneyTransaction& t,
@@ -59,8 +60,8 @@ public:
const bool amountValid,
const bool deposit,
const MyMoneyMoney& calculatedValue,
- const QMap<QString, MyMoneyMoney>& priceInfo,
- QWidget* parent = 0, const char* name = 0);
+ const TQMap<TQString, MyMoneyMoney>& priceInfo,
+ TQWidget* tqparent = 0, const char* name = 0);
virtual ~KSplitTransactionDlg();
@@ -106,7 +107,7 @@ protected slots:
void slotClearAllSplits(void);
void slotClearUnusedSplits(void);
void slotSetTransaction(const MyMoneyTransaction& t);
- void slotCreateCategory(const QString& txt, QString& id);
+ void slotCreateCategory(const TQString& txt, TQString& id);
void slotMergeSplits(void);
/// used internally to setup the initial size of all widgets
@@ -115,13 +116,13 @@ protected slots:
signals:
/**
* This signal is sent out, when a new category needs to be created
* Depending on the setting of either a payment or deposit, the parent
* account will be preset to Expense or Income.
*
* @param account reference to account info. Will be filled by called slot
* @param parent reference to parent account
*/
- void createCategory(MyMoneyAccount& account, const MyMoneyAccount& parent);
+ void createCategory(MyMoneyAccount& account, const MyMoneyAccount& tqparent);
/**
* Signal is emitted, if any of the widgets enters (@a state equals @a true)
@@ -115,13 +116,13 @@ protected slots:
/**
* This signal is sent out, when a new category needs to be created
- * Depending on the setting of either a payment or deposit, the parent
+ * Depending on the setting of either a payment or deposit, the tqparent
* account will be preset to Expense or Income.
*
@@ -115,13 +116,13 @@ protected slots:
*
* @param account reference to account info. Will be filled by called slot
- * @param parent reference to parent account
+ * @param tqparent reference to tqparent account
*/